@@ -1,3 +1,7 @@
+import os
+import sys
+import sh
+import tempfile
 from pytest import raises
 from lyncs_mpi import (
     Client,
@@ -28,3 +32,20 @@ def test_client():
 
     client = Client(num_workers=1)
     client.__del__()
+
+
+def test_not_launch():
+    with raises(RuntimeError):
+        Client(launch=False)
+
+    pwd = os.getcwd()
+    sh.cd(tempfile.mkdtemp())
+    test = sh.mpirun(
+        "-n",
+        3,
+        sys.executable,
+        "-c",
+        "from lyncs_mpi import Client; Client(1, launch=False)",
+    )
+    sh.cd(pwd)
+    assert test.exit_code == 0
